@@ -6,9 +6,9 @@ Type annotations for chime-sdk-identity service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_identity.literals import ServiceName
+    from mypy_boto3_chime_sdk_identity.literals import AllowMessagesType
 
-    data: ServiceName = "accessanalyzer"
+    data: AllowMessagesType = "ALL"
     ```
 """
 import sys
@@ -19,9 +19,19 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ServiceName",)
+__all__ = (
+    "AllowMessagesType",
+    "AppInstanceUserEndpointTypeType",
+    "EndpointStatusReasonType",
+    "EndpointStatusType",
+    "ServiceName",
+)
 
 
+AllowMessagesType = Literal["ALL", "NONE"]
+AppInstanceUserEndpointTypeType = Literal["APNS", "APNS_SANDBOX", "GCM"]
+EndpointStatusReasonType = Literal["INVALID_DEVICE_TOKEN", "INVALID_PINPOINT_ARN"]
+EndpointStatusType = Literal["ACTIVE", "INACTIVE"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
